@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=1f7e168
+MEDIALIBRARY_HASH=786131a
 
 BUILD_ML=1
 RELEASE=0
@@ -281,14 +281,17 @@ VLC_CONTRIB="$VLC_SRC_DIR/contrib/$TARGET_TUPLE"
 # try to detect NDK version
 REL=$(grep -o '^Pkg.Revision.*[0-9]*.*' $ANDROID_NDK/source.properties |cut -d " " -f 3 | cut -d "." -f 1)
 
-if [ "$REL" -ge 13 ]; then
+# NDK 15 and after drops support for old android platforms (bellow
+# ANDROID_API=14) but these platforms are still supported by VLC 3.0.
+# TODO: Switch to NDK 15 when we drop support for old android plaftorms (for VLC 4.0)
+if [ "$REL" -eq 14 ]; then
     if [ "${HAVE_64}" = 1 ];then
         ANDROID_API=21
     else
         ANDROID_API=9
     fi
 else
-    echo "You need the NDKv13 or later"
+    echo "NDK v14 needed, cf. https://developer.android.com/ndk/downloads/older_releases.html#ndk-14-downloads"
     exit 1
 fi
 
