@@ -37,8 +37,6 @@ mkdir -p "$TMP_PATH"/jni
 
 cp -r "$SCRIPT_PATH"/libvlc/jni/libs "$TMP_PATH"
 cp -r "$SCRIPT_PATH"/libvlc/jni/obj "$TMP_PATH"
-cp -r "$SCRIPT_PATH"/medialibrary/jni/libs "$TMP_PATH"
-cp -r "$SCRIPT_PATH"/medialibrary/jni/obj "$TMP_PATH"
 
 ln -s "$TMP_PATH"/obj "$TMP_PATH"/jni
 
