@@ -53,7 +53,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>, PlaylistAdapter.ViewHolder> implements SwipeDragHelperAdapter, Filterable {
+public class PlaylistAdapter extends BaseQueuedAdapter<MediaWrapper, PlaylistAdapter.ViewHolder> implements SwipeDragHelperAdapter, Filterable {
 
     private static final String TAG = "VLC/PlaylistAdapter";
 
@@ -61,7 +61,6 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
     private PlaybackService mService = null;
     private IPlayer mAudioPlayer;
 
-    private volatile ArrayList<MediaWrapper> mDataSet = new ArrayList<>();
     private ArrayList<MediaWrapper> mOriginalDataSet;
     private int mCurrentIndex = 0;
 
@@ -96,13 +95,13 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
 
     @Override
     public int getItemCount() {
-        return mDataSet.size();
+        return mDataset.size();
     }
 
     @MainThread
     public MediaWrapper getItem(int position) {
         if (position >= 0 && position < getItemCount())
-            return mDataSet.get(position);
+            return mDataset.get(position);
         else
             return null;
     }
@@ -119,29 +118,13 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
 
     @MainThread
     public void addAll(List<MediaWrapper> playList) {
-        mDataSet.addAll(playList);
+        mDataset.addAll(playList);
     }
 
-    @MainThread
-    protected void internalUpdate(final ArrayList<MediaWrapper> newList, final boolean detectMoves) {
-        VLCApplication.runBackground(new Runnable() {
-            @Override
-            public void run() {
-                final DiffUtil.DiffResult result = DiffUtil.calculateDiff(new MediaItemDiffCallback(mDataSet, newList), detectMoves);
-                VLCApplication.runOnMainThread(new Runnable() {
-                    @Override
-                    public void run() {
-                        mDataSet.clear();
-                        addAll(newList);
-                        result.dispatchUpdatesTo(PlaylistAdapter.this);
-                        if (mService != null)
-                            setCurrentIndex(mService.getCurrentMediaPosition());
-                        processQueue();
-                    }
-                });
-            }
-        });
-
+    @Override
+    protected void onUpdateFinished() {
+        if (mService != null)
+            setCurrentIndex(mService.getCurrentMediaPosition());
     }
 
     @MainThread
@@ -167,7 +150,7 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
 
     @Override
     public void onItemMove(int fromPosition, int toPosition) {
-        Collections.swap(mDataSet, fromPosition, toPosition);
+        Collections.swap(mDataset, fromPosition, toPosition);
         notifyItemMoved(fromPosition, toPosition);
         mHandler.obtainMessage(PlaylistHandler.ACTION_MOVE, fromPosition, toPosition).sendToTarget();
     }
@@ -278,7 +261,7 @@ public class PlaylistAdapter extends BaseQueuedAdapter<ArrayList<MediaWrapper>,
         @Override
         protected FilterResults performFiltering(CharSequence charSequence) {
             if (mOriginalDataSet == null)
-                mOriginalDataSet = new ArrayList<>(mDataSet);
+                mOriginalDataSet = new ArrayList<>(mDataset);
             final String[] queryStrings = charSequence.toString().trim().toLowerCase().split(" ");
             FilterResults results = new FilterResults();
             ArrayList<MediaWrapper> list = new ArrayList<>();
